@@ -16,11 +16,13 @@ use Array::AsHash;
 use Array::OrdHash;
 use Data::XHash;
 
-use constant COUNT => 5;
+use constant COUNT => $ENV{COUNT} // 5;
 use constant NUMS => [ 10, 100, 1000 ];
 
 STDOUT->autoflush(1);
 
+my %FILTER = $ENV{FILTER} ? ( map { $_ => 1 } split /,/, $ENV{FILTER} ) : ();
+
 my %PAIRS = (
     map {
         $_ => [ map { irand() => irand() } 1 .. $_ ]
@@ -31,14 +33,16 @@ sub time_them {
     my (%mark) = @_;
     my %results;
 
-    for my $k ( sort keys %mark ) {
+    my @mods = grep { %FILTER ? $FILTER{$_} : 1 } sort keys %mark;
+
+    for my $k (@mods) {
 ##        warn "Timing $k...\n";
         my $res = countit( COUNT, $mark{$k} );
         my $iter_s = $res->iters / ( $res->cpu_a + 1e-9 );
         $results{$k} = $iter_s;
     }
 
-    printf( "%20s %d/s\n", $_, $results{$_} )
+    printf( "%20s %10s%s\n", $_, int( $results{$_} ) . "/s", $_ =~ /^h:o/ ? "  *" : "" )
       for sort { $results{$b} <=> $results{$a} } keys %results;
 
     say "";
@@ -53,7 +57,7 @@ my %TESTS;
 $TESTS{create} = sub {
     for my $size ( @{ NUMS() } ) {
 
-        say my $title = "Results for ordered hash creation for $size elements";
+        say my $title = "    Results for ordered hash creation for $size elements";
 
         my %mark;
 
@@ -112,7 +116,7 @@ $TESTS{create} = sub {
 $TESTS{get} = sub {
     for my $size ( @{ NUMS() } ) {
 
-        say my $title = "Results for fetching ~10% of $size elements";
+        say my $title = "    Results for fetching ~10% of $size elements";
 
         my $oh     = Hash::Ordered->new( @{ $PAIRS{$size} } );
         my $tix_oo = Tie::IxHash->new( @{ $PAIRS{$size} } );
@@ -152,7 +156,7 @@ $TESTS{get} = sub {
 $TESTS{replace} = sub {
     for my $size ( @{ NUMS() } ) {
 
-        say my $title = "Results for replacing ~10% of $size elements";
+        say my $title = "    Results for replacing ~10% of $size elements";
 
         my $oh     = Hash::Ordered->new( @{ $PAIRS{$size} } );
         my $tix_oo = Tie::IxHash->new( @{ $PAIRS{$size} } );
@@ -193,7 +197,7 @@ $TESTS{replace} = sub {
 $TESTS{add} = sub {
     for my $size ( @{ NUMS() } ) {
 
-        say my $title = "Results for adding $size elements to empty hash";
+        say my $title = "    Results for adding $size elements to empty hash";
 
         my ( %mark, $v );
         my @keys = keys %{ { @{ $PAIRS{$size} } } };
@@ -267,7 +271,7 @@ $TESTS{add} = sub {
 $TESTS{delete} = sub {
     for my $size ( @{ NUMS() } ) {
 
-        say my $title = "Results for creating $size element hash then deleting ~10%";
+        say my $title = "    Results for creating $size element hash then deleting ~10%";
 
         my ( %mark, $v );
         my @keys = keys %{ { @{ $PAIRS{$size} } } };
@@ -336,7 +340,7 @@ $TESTS{delete} = sub {
 $TESTS{list} = sub {
     for my $size ( @{ NUMS() } ) {
 
-        say my $title = "Results for listing pairs of $size element hash";
+        say my $title = "    Results for listing pairs of $size element hash";
 
         my $oh     = Hash::Ordered->new( @{ $PAIRS{$size} } );
         my $tix_oo = Tie::IxHash->new( @{ $PAIRS{$size} } );
@@ -370,7 +374,9 @@ $TESTS{list} = sub {
 # main program
 #--------------------------------------------------------------------------#
 
-for my $run ( @ARGV ? @ARGV : sort keys %TESTS ) {
+my @order = qw/create get replace add delete list/;
+
+for my $run ( @ARGV ? @ARGV : @order ) {
     if ( my $sub = $TESTS{$run} ) {
         $sub->();
     }
