@@ -5,7 +5,7 @@ use warnings;
 package Hash::Ordered;
 # ABSTRACT: A fast, pure-Perl ordered hash class
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use Carp ();
 
@@ -60,17 +60,18 @@ use overload
 #pod =cut
 
 sub new {
-    my ( $class, @pairs ) = @_;
+    my $class = shift;
 
-    return bless [ {}, [], undef, 0, 0 ], $class unless @pairs;
+    return bless [ {}, [], undef, 0, 0 ], $class unless @_;
 
-    Carp::croak("new() requires key-value pairs") unless @pairs % 2 == 0;
+    Carp::croak("new() requires key-value pairs") unless @_ % 2 == 0;
 
     # must stringify keys for _KEYS array
-    my $self = [
-        {@pairs}, [ map { $_ % 2 == 0 ? ("$pairs[$_]") : () } 0 .. $#pairs ],
-        undef, 0, 0
-    ];
+    my @keys;
+    for ( my $i = 0; $i < $#_; $i += 2 ) {
+        push @keys, "$_[$i]";
+    }
+    my $self = [ {@_}, \@keys, undef, 0, 0 ];
 
     return bless $self, $class;
 }
@@ -89,12 +90,11 @@ sub new {
 
 sub clone {
     my $self = CORE::shift;
-    my @keys = map { "$_" } @_; # stringify keys
     my $clone;
-    if (@keys) {
+    if (@_) {
         my %subhash;
-        @subhash{@keys} = @{ $self->[_DATA] }{@keys};
-        $clone = [ \%subhash, \@keys, undef, 0, 0 ];
+        @subhash{@_} = @{ $self->[_DATA] }{@_};
+        $clone = [ \%subhash, [ map "$_", @_ ], undef, 0, 0 ];
     }
     elsif ( $self->[_INDX] ) {
         $clone =
@@ -144,11 +144,10 @@ sub keys {
 #pod =cut
 
 sub values {
-    my ( $self, @keys ) = @_;
+    my $self = CORE::shift;
     return
       wantarray
-      ? ( map { $self->[_DATA]{$_} }
-          ( @keys ? @keys : grep !ref($_), @{ $self->[_KEYS] } ) )
+      ? ( map { $self->[_DATA]{$_} } ( @_ ? @_ : grep !ref($_), @{ $self->[_KEYS] } ) )
       : @{ $self->[_KEYS] } - $self->[_GCNT];
 }
 
@@ -287,10 +286,10 @@ sub clear {
 #pod =cut
 
 sub push {
-    my ( $self, @pairs ) = @_;
+    my $self = CORE::shift;
     my ( $data, $keys, $indx ) = @$self;
-    while (@pairs) {
-        my ( $k, $v ) = splice( @pairs, 0, 2 );
+    while (@_) {
+        my ( $k, $v ) = splice( @_, 0, 2 );
         $self->delete($k) if exists $data->{$k};
         $data->{$k} = $v;
         CORE::push @$keys, "$k"; # stringify keys
@@ -332,10 +331,10 @@ sub pop {
 #pod =cut
 
 sub unshift {
-    my ( $self, @pairs ) = @_;
+    my $self = CORE::shift;
     my ( $data, $keys, $indx ) = @$self;
-    while (@pairs) {
-        my ( $k, $v ) = splice( @pairs, -2, 2 );
+    while (@_) {
+        my ( $k, $v ) = splice( @_, -2, 2 );
         $self->delete($k) if exists $data->{$k};
         $data->{$k} = $v;
         CORE::unshift @$keys, "$k"; # stringify keys
@@ -375,9 +374,9 @@ sub shift {
 #pod =cut
 
 sub merge {
-    my ( $self, @pairs ) = @_;
-    while (@pairs) {
-        my ( $k, $v ) = splice( @pairs, -2, 2 );
+    my $self = CORE::shift;
+    while (@_) {
+        my ( $k, $v ) = splice( @_, -2, 2 );
         if ( !exists $self->[_DATA]{$k} ) {
             my $size = CORE::push @{ $self->[_KEYS] }, "$k"; # stringify key
             $self->[_INDX]{$k} = $size - 1 if $self->[_INDX];
@@ -400,10 +399,10 @@ sub merge {
 #pod =cut
 
 sub as_list {
-    my ( $self, @keys ) = @_;
+    my $self = CORE::shift;
     return
       map { ; $_ => $self->[_DATA]{$_} }
-      ( @keys ? @keys : grep !ref($_), @{ $self->[_KEYS] } );
+      ( @_ ? @_ : grep !ref($_), @{ $self->[_KEYS] } );
 }
 
 #pod =method iterator
@@ -426,6 +425,7 @@ sub as_list {
 #pod
 #pod =cut
 
+# usually we avoid copying keys in @_; here we must for the closure
 sub iterator {
     my ( $self, @keys ) = @_;
     @keys = grep !ref($_), @{ $self->[_KEYS] } unless @keys;
@@ -654,7 +654,7 @@ Hash::Ordered - A fast, pure-Perl ordered hash class
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -1047,19 +1047,24 @@ benchmarking results, see L<Hash::Ordered::Benchmarks>.
 
 =head2 Tie modules
 
-The following modules offer some sort of tie interface.  I don't like ties, in
-general, because of the extra indirection involved over a direct method call,
-but if you are willing to pay that penalty, you might want to try one of these.
+The following modules offer some sort of tie interface.  I don't like ties,
+in general, because of the extra indirection involved over a direct method
+call. Still, you can make any tied interface into a faster OO one with
+C<tied>:
 
-L<Tie::IxHash> is probably the most well known and includes an OO API.  If its
-warts and performance profile aren't a problem, it might serve.
+    tied( %tied_hash )->FETCH($key);
 
-L<Tie::Hash::Indexed> is implemented in XS and thus seems promising if pure-Perl
-isn't a criterion; it often fails tests on Perl 5.18 and above due to the hash
-randomization change.
+L<Tie::Hash::Indexed> is implemented in XS and thus seems promising if
+pure-Perl isn't a criterion; it generally fails tests on Perl 5.18 and
+above due to the hash randomization change.  Despite being XS, it is slower
+than Hash::Ordered at everything exception creation and deletion.
 
-These other modules below have very specific designs/limitations and I didn't
-find any of them suitable for general purpose use:
+L<Tie::IxHash> is probably the most well known and includes an OO API.
+Given the performance problems it has, "well known" is the only real reason
+to use it.
+
+These other modules below have very specific designs/limitations and I
+didn't find any of them suitable for general purpose use:
 
 =over 4
 
@@ -1099,8 +1104,8 @@ items up to 10x slower than Hash::Ordered.
 
 However, C<Array::AsHash> takes an arrayref to initialize, which is very
 fast and can return the list of pairs faster, too.  If you mostly create
-and list out ordered hashes and very rarely touch individual entries, I
-think this could be something to very cautiously consider.
+and list out very large ordered hashes and very rarely touch individual
+entries, I think this could be something to very cautiously consider.
 
 These other modules below have restrictions or particularly complicated
 implementations (often relying on C<tie>) and thus I didn't think any of
